Struct plaid::liabilities::APR[][src]

pub struct APR {
    pub apr_percentage: f64,
    pub apr_type: String,
    pub balance_subject_to_api: Option<f64>,
    pub interest_charge_amount: Option<f64>,
}

Fields

apr_percentage: f64

Annual Percentage Rate applied.

apr_type: String

The type of balance to which the APR applies. Possible values: balance_transfer_apr, cash_apr, purchase_apr, special

balance_subject_to_api: Option<f64>

Amount of money that is subjected to the APR if a balance was carried beyond payment due date. How it is calculated can vary by card issuer. It is often calculated as an average daily balance.

interest_charge_amount: Option<f64>

Amount of money charged due to interest from last statement.