Struct plaid::liabilities::CreditLiability[][src]

pub struct CreditLiability {
    pub account_id: Option<String>,
    pub aprs: Vec<APR>,
    pub is_overdue: Option<bool>,
    pub last_payment_amount: f64,
    pub last_payment_date: Option<NaiveDate>,
    pub last_statement_balance: f64,
    pub last_statement_issue_date: NaiveDate,
    pub minimum_payment_amount: f64,
    pub next_payment_due_date: Option<NaiveDate>,
}

Fields

account_id: Option<String>

The ID of the account that this liability belongs to.

aprs: Vec<APR>

The various interest rates that apply to the account.

is_overdue: Option<bool>

true if a payment is currently overdue. Availability for this field is limited.

last_payment_amount: f64

The amount of the last payment.

last_payment_date: Option<NaiveDate>

The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD). Availability for this field is limited.

last_statement_balance: f64

The outstanding balance on the last statement. Availability for this field is limited.

last_statement_issue_date: NaiveDate

The date of the last statement. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

minimum_payment_amount: f64

The minimum payment due for the next billing cycle.

next_payment_due_date: Option<NaiveDate>

The due date for the next payment. The due date is null if a payment is not expected. Dates are returned in an ISO 8601 format (YYYY-MM-DD).