Struct plaid::liabilities::GetLiabilitiesResponse[][src]

pub struct GetLiabilitiesResponse {
    pub request_id: String,
    pub accounts: Vec<Account>,
    pub item: Item,
    pub liabilities: Liabilities,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

accounts: Vec<Account>

The accounts for which transaction history is being fetched.

item: Item

Metadata about the Item.

liabilities: Liabilities

An object containing liability accounts