Struct plaid::liabilities::StudentLoanLiability[][src]

pub struct StudentLoanLiability {
    pub account_id: Option<String>,
    pub account_number: Option<String>,
    pub disbursement_dates: Option<Vec<NaiveDate>>,
    pub expected_payoff_date: Option<String>,
    pub guarantor: Option<String>,
    pub interest_rate_percentage: f64,
    pub is_overdue: Option<bool>,
    pub last_payment_amount: Option<f64>,
    pub last_payment_date: Option<NaiveDate>,
    pub last_statement_balance: Option<f64>,
    pub last_statement_issue_date: Option<NaiveDate>,
    pub loan_name: Option<String>,
    pub loan_status: StudentLoanStatus,
    pub minimum_payment_amount: Option<f64>,
    pub next_payment_due_date: Option<NaiveDate>,
    pub origination_date: Option<NaiveDate>,
    pub origination_principal_amount: Option<f64>,
    pub origination_interest_amount: Option<f64>,
    pub payment_reference_number: Option<String>,
    pub pslf_status: PSLFStatus,
    pub repayment_plan: StudentLoanRepaymentPlan,
    pub sequence_number: Option<String>,
    pub servicer_address: StudentLoanServicerAddress,
    pub ytd_interest_paid: Option<f64>,
    pub ytd_principal_paid: Option<f64>,
}

Fields

account_id: Option<String>

The ID of the account that this liability belongs to.

account_number: Option<String>

The account number of the loan.

disbursement_dates: Option<Vec<NaiveDate>>

The dates on which loaned funds were disbursed or will be disbursed. These are often in the past. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

expected_payoff_date: Option<String>

The date when the student loan is expected to be paid off. Availability for this field is limited. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

guarantor: Option<String>

The guarantor of the student loan.

interest_rate_percentage: f64

The interest rate on the loan as a percentage.

is_overdue: Option<bool>

true if a payment is currently overdue. Availability for this field is limited.

last_payment_amount: Option<f64>

The amount of the last payment.

last_payment_date: Option<NaiveDate>

The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

last_statement_balance: Option<f64>

The outstanding balance on the last statement. This field could also be interpreted as the next payment due. Availability for this field is limited.

last_statement_issue_date: Option<NaiveDate>

The date of the last statement. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

loan_name: Option<String>

The type of loan, e.g., "Consolidation Loans".

loan_status: StudentLoanStatus

An object representing the status of the student loan

minimum_payment_amount: Option<f64>

The minimum payment due for the next billing cycle.

next_payment_due_date: Option<NaiveDate>

The due date for the next payment.

origination_date: Option<NaiveDate>

The date on which the loan was initially lent. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

origination_principal_amount: Option<f64>

The original principal balance of the loan.

origination_interest_amount: Option<f64>

The total dollar amount of the accrued interest balance. For Sallie Mae ( ins_116944), this amount is included in the current balance of the loan, so this field will return as null.

payment_reference_number: Option<String>

The relevant account number that should be used to reference this loan for payments. In the majority of cases, payment_reference_number will match account_number, but in some institutions, such as Great Lakes (ins_116861), it will be different.

pslf_status: PSLFStatus

Information about the student's eligibility in the Public Service Loan Forgiveness program. This is only returned if the institution is Fedloan (ins_116527).

repayment_plan: StudentLoanRepaymentPlan

An object representing the repayment plan for the student loan

sequence_number: Option<String>

The sequence number of the student loan. Heartland ECSI (ins_116948) does not make this field available.

servicer_address: StudentLoanServicerAddress

The address of the student loan servicer. This is generally the remittance address to which payments should be sent.

ytd_interest_paid: Option<f64>

The year to date (YTD) interest paid. Availability for this field is limited.

ytd_principal_paid: Option<f64>

The year to date (YTD) principal paid. Availability for this field is limited.