Struct plaid::liabilities::StudentLoanStatus[][src]

pub struct StudentLoanStatus {
    pub end_date: Option<NaiveDate>,
    pub type: Option<String>,
}

Fields

end_date: Option<NaiveDate>

The date until which the loan will be in its current status. Dates are returned in an ISO 8601 format (YYYY-MM-DD).

type: Option<String>

The status type of the student loan Possible values: cancelled, charged off, claim, consolidated, deferment, delinquent, discharged, extension, forbearance, in grace, in military, in school, not fully disbursed, other, paid in full, refunded, repayment, transferred