Struct plaid::liabilities::APR [−][src]
Fields
apr_percentage: f64Annual Percentage Rate applied.
apr_type: StringThe type of balance to which the APR applies. Possible values: balance_transfer_apr, cash_apr, purchase_apr, special
balance_subject_to_api: Option<f64>Amount of money that is subjected to the APR if a balance was carried beyond payment due date. How it is calculated can vary by card issuer. It is often calculated as an average daily balance.
interest_charge_amount: Option<f64>Amount of money charged due to interest from last statement.