Struct plaid::liabilities::MortgageLiability [−][src]
Fields
account_id: Option<String>The ID of the account that this liability belongs to.
account_number: StringThe account number of the loan.
current_late_fee: Option<f64>The current outstanding amount charged for late payment.
escrow_balance: Option<f64>Total amount held in escrow to pay taxes and insurance on behalf of the borrower.
has_pmi: Option<bool>Indicates whether the borrower has private mortgage insurance in effect.
has_prepayment_penalty: Option<bool>Indicates whether the borrower will pay a penalty for early payoff of mortgage.
interest_rate: MortgageInterestRateObject containing metadata about the interest rate for the mortgage.
last_payment_amount: Option<f64>The amount of the last payment.
last_payment_date: Option<NaiveDate>The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).
loan_type_descrption: Option<String>Description of the type of loan, for example conventional, fixed, or variable. This field is provided directly from the loan servicer and does not have an enumerated set of possible values.
loan_term: Option<String>Full duration of mortgage as at origination (e.g. 10 year).
maturity_date: Option<NaiveDate>Original date on which mortgage is due in full. Dates are returned in an ISO 8601 format (YYYY-MM-DD).
next_monthly_payment: Option<f64>The amount of the next payment.
next_payment_due_date: Option<NaiveDate>The due date for the next payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).
origination_date: Option<NaiveDate>The date on which the loan was initially lent. Dates are returned in an ISO 8601 format (YYYY-MM-DD).
origination_principal_amount: Option<f64>The original principal balance of the mortgage.
past_due_amount: Option<f64>Amount of loan (principal + interest) past due for payment.
property_address: MortgagePropertyAddressObject containing fields describing property address.
ytd_interest_paid: Option<f64>The year to date (YTD) interest paid.
ytd_principal_paid: Option<f64>The YTD principal paid.